/*
	Zadatak: Case
	Autor resenja: Aleksandar Ilic, aleksandari@gmail.com

	Resenje je ITERATIVNA metoda (kao Paskalov trougao).
	Za svaki red pamtimo nizove p [] i q [], koji predstavljaju brojilac i imenilac razlomka 
	kolicine sampanjca u odgovarajucoj casi. Primetimo da nam nije potrebna matrica, vec samo 
	poslednji red za generisanje novog. Za svaki red sa desna na levo racunamo kolicine sabirajuci 
	razlomke. Sabiranje i oduzimanje razlomaka se vrsi svodjenjem na zajednicki sadrzalac.
	Imenilac svakog razlomka je stepen dvojke, pa je olaksano nalazenje najmanjeg zajednickog 
	sadrzaoca. Na kraju treba proveriti da li je case puna ili prazna ili delimicno puna.
	Zbog ogranicenja u zadatku potrebno je raditi sa realnim brojevima, jer se 32-bitni integeri
	probijaju pri velikim n.

	Slozenost: O (n)
*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define MaxN 100

long v, w, n;
double psol, qsol;

// procedura za unos ulaznih podataka: v, w, n
void Input ()
{
	FILE *in;

	in = fopen ("zad2.dat", "r");
	fscanf (in, "%ld %ld %ld", &v, &w, &n);
	fclose (in);
}

// procedura za ispis resenja u obliku razlomka
void Output ()
{
	FILE *out;

	out = fopen ("zad2.res", "w");
	fprintf (out, "%0.0lf/%0.0lf\n", psol, qsol);
	printf ("%0.0lf/%0.0lf\n", psol, qsol);
	fclose (out);
}

// procedura za najveci zajednicki delilac brojeva a i b, gde je b = 2^k
double Nzd (double a, double b)
{
	double d;

	d = 1.0;
	while ((fabs (2 * floor (a / 2) - a) < 1e-10) && (fabs (2 * floor (b / 2) - b) < 1e-10))
	{
		a = a / 2;
		b = b / 2;
		d = d * 2;
	}
	return (d);
}

// glavna procedura koja resava problem
void Solve ()
{
	long i, j, k;
	double d, p [MaxN], q [MaxN];
	
	for (i = 0; i < MaxN; i++)
	{
		p [i] = 0;
		q [i] = 1;
	}
	p [1] = w;
	q [1] = 1;
	i = 1;
	k = 1;
	while (k < n)
	{
		i++;
		k = k + i;
		for (j = i - 1; j >= 1; j--)
			if (p [j] > q [j] * v)
			{
				p [j] = p [j] - q [j] * v;
				q [j] = 2 * q [j];
				d = Nzd (p [j], q [j]);
				if (d > 1)
				{
					p [j] = p [j] / d;
					q [j] = q [j] / d;
				}
				d = Nzd (q [j + 1], q [j]);
				p [j + 1] = p [j + 1] * (q [j] / d) + p [j] * (q [j + 1] / d);
				q [j + 1] = q [j + 1] * (q [j] / d);
				d = Nzd (p [j + 1], q [j + 1]);
				if (d > 1)
				{
					p [j + 1] = p [j + 1] / d;
					q [j + 1] = q [j + 1] / d;
				}
			}
			else
			{
				p [j] = 0;
				q [j] = 1;
			}
	}
	psol = p [k - n + 1];
	qsol = q [k - n + 1];
	if (psol > v * qsol)
	{
		psol = v;
		qsol = 1;

	}
}

void main ()
{
	Input ();
	Solve ();
	Output ();
}
